# Twinnterface

[![PyPI Latest Release](https://img.shields.io/pypi/v/twinnterface.svg)](https://pypi.org/project/twinnterface/)
[![Downloads](https://static.pepy.tech/personalized-badge/twinnterface?period=month&units=international_system&left_color=black&right_color=orange&left_text=PyPI%20downloads%20per%20month)](https://pepy.tech/project/twinnterface)
[![License](https://img.shields.io/pypi/l/twinnterface.svg)](https://github.com/ruudkassing/twinnterface/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

**COMING SOON!**

Twinnterface (Twinn Interface) is a Python package for *data contracts between machine learning code and infrastructure*.

Author: [Royal HaskoningDHV](https://global.royalhaskoningdhv.com/)

Email: [ruud.kassing@rhdhv.com](mailto:ruud.kassing@rhdhv.com)

## Getting started
**COMING SOON!**

### Installation

The easiest way to install is package is using pip:
```
pip install twinnterface
```